@@ -990,19 +990,35 @@ class TcpServerChannel:  # pylint: disable=too-many-instance-attributes
 
     async def _handle_message(self, message: Request, peer_name: str) -> None:
         """Handle a single message from a peer."""
-        req_type = message.WhichOneof("value")
-        self.logger.debug(f"Received message of type: {req_type}")
-        result = _TendermintProtocolDecoder.process(
-            message, self._dialogues, str(self.target_skill_id)
-        )
-        if result is not None:
-            request, dialogue = result
-            # associate request to peer, so we remember who to reply to
-            self._request_id_to_socket[dialogue.incomplete_dialogue_label] = peer_name
-            envelope = Envelope(to=request.to, sender=request.sender, message=request)
-            await cast(asyncio.Queue, self.queue).put(envelope)
-        else:  # pragma: nocover
-            self.logger.warning(f"Decoded request {req_type} was not a match.")
+        # TODO: remove the following try/except and logs, https://github.com/valory-xyz/open-autonomy/issues/1655
+        try:
+            req_type = message.WhichOneof("value")
+            self.logger.info(
+                f"Received message of type: {req_type} on abci connection."
+            )
+            result = _TendermintProtocolDecoder.process(
+                message, self._dialogues, str(self.target_skill_id)
+            )
+            self.logger.info(f"Received result={result} from processing message.")
+            if result is not None:
+                request, dialogue = result
+                # associate request to peer, so we remember who to reply to
+                self._request_id_to_socket[
+                    dialogue.incomplete_dialogue_label
+                ] = peer_name
+                self.logger.info(
+                    f"Associated request with id={dialogue.incomplete_dialogue_label} to peer={peer_name}."
+                )
+                envelope = Envelope(
+                    to=request.to, sender=request.sender, message=request
+                )
+                self.logger.info(f"Created envelope={envelope}.")
+                await cast(asyncio.Queue, self.queue).put(envelope)
+                self.logger.info(f"Successfully put envelope in queue={envelope}.")
+            else:  # pragma: nocover
+                self.logger.warning(f"Decoded request {req_type} was not a match.")
+        except Exception as e:  # pylint: disable=broad-except
+            self.logger.error(f"Unhandled exception {type(e).__name__}: {e}")
 
     async def get_message(self) -> Envelope:
         """Get a message from the queue."""
@@ -1026,7 +1042,9 @@ class TcpServerChannel:  # pylint: disable=too-many-instance-attributes
         writer.write(data)
 
 
-class StoppableThread(Thread):
+class StoppableThread(
+    Thread,
+):  # pragma: no cover (covered via deployments/Dockerfiles/tendermint/tendermint.py)
     """Thread class with a stop() method."""
 
     def __init__(self, *args: Any, **kwargs: Any) -> None:
@@ -1043,7 +1061,7 @@ class StoppableThread(Thread):
         return self._stop_event.is_set()
 
 
-class TendermintParams:  # pylint: disable=too-few-public-methods
+class TendermintParams:  # pylint: disable=too-few-public-methods  # pragma: no cover (covered via deployments/Dockerfiles/tendermint/tendermint.py)
     """Tendermint node parameters."""
 
     def __init__(  # pylint: disable=too-many-arguments
@@ -1128,7 +1146,7 @@ class TendermintParams:  # pylint: disable=too-few-public-methods
         return kwargs
 
 
-class TendermintNode:
+class TendermintNode:  # pragma: no cover (covered via deployments/Dockerfiles/tendermint/tendermint.py)
     """A class to manage a Tendermint node."""
 
     def __init__(self, params: TendermintParams, logger: Optional[Logger] = None):
@@ -1430,6 +1448,11 @@ class ABCIServerConnection(Connection):  # pylint: disable=too-many-instance-att
         self._ensure_connected()
         self.channel = cast(Union[TcpServerChannel, GrpcServerChannel], self.channel)
         try:
-            return await self.channel.get_message()
+            message = await self.channel.get_message()
+            # TODO: remove the following, https://github.com/valory-xyz/open-autonomy/issues/1655
+            self.logger.info(
+                f"Received message={message} on `ABCIServerConnection.receive()`."
+            )
+            return message
         except CancelledError:  # pragma: no cover
             return None
