@@ -19,6 +19,7 @@
 
 """This module contains utilities for AbciApps."""
 import logging
+from copy import deepcopy
 from typing import Any, Dict, List, Optional, Set, Tuple, Type
 
 from aea.exceptions import enforce
@@ -50,11 +51,18 @@ def check_set_uniqueness(sets: Tuple) -> Optional[Any]:
     return None
 
 
-def chain(  # pylint: disable=too-many-locals
+def chain(  # pylint: disable=too-many-locals,too-many-statements
     abci_apps: Tuple[Type[AbciApp], ...],
     abci_app_transition_mapping: AbciAppTransitionMapping,
 ) -> Type[AbciApp]:
-    """Concatenate multiple AbciApp types."""
+    """
+    Concatenate multiple AbciApp types.
+
+    The consistency checks assume that the first element in
+    abci_apps is the entry-point abci_app (i.e. the associated round of
+    the  initial_behaviour_cls of the AbstractRoundBehaviour in which
+    the chained AbciApp is used is one of the initial_states of the first element.)
+    """
     enforce(
         len(abci_apps) > 1,
         f"there must be a minimum of two AbciApps to chain, found ({len(abci_apps)})",
@@ -74,7 +82,7 @@ def chain(  # pylint: disable=too-many-locals
     # Get the apps rounds
     rounds = tuple(app.get_all_rounds() for app in abci_apps)
     round_ids = tuple(
-        {round_.round_id for round_ in app.get_all_rounds()} for app in abci_apps
+        {round_.auto_round_id() for round_ in app.get_all_rounds()} for app in abci_apps
     )
 
     # Ensure there are no common rounds
@@ -108,6 +116,96 @@ def chain(  # pylint: disable=too-many-locals
                 f"Found non-initial state {value} specified in abci_app_transition_mapping."
             )
 
+    # Ensure all DB pre- and post-conditions are consistent
+    # Since we know which app is the "entry-point" we can
+    # simply work forward from there through all branches. When
+    # we loop back on an earlier node we stop.
+    initial_state_to_app: Dict[AppState, Type[AbciApp]] = {}
+    for value in abci_app_transition_mapping.values():
+        for app in abci_apps:
+            if value in app.initial_states or value == app.initial_round_cls:
+                initial_state_to_app[value] = app
+                break
+
+    def get_paths(
+        initial_state: AppState,
+        app: Type[AbciApp],
+        previous_apps: Optional[List[Type[AbciApp]]] = None,
+    ) -> List[List[Tuple[AppState, Type[AbciApp], Optional[AppState]]]]:
+        """Get paths."""
+        previous_apps_: List[Type[AbciApp]] = (
+            deepcopy(previous_apps) if previous_apps is not None else []
+        )
+        default: List[List[Tuple[AppState, Type[AbciApp], Optional[AppState]]]] = [
+            [(initial_state, app, None)]
+        ]
+        if app.final_states == {}:
+            return default
+        paths: List[List[Tuple[AppState, Type[AbciApp], Optional[AppState]]]] = []
+        for final_state in app.final_states:
+            element: Tuple[AppState, Type[AbciApp], Optional[AppState]] = (
+                initial_state,
+                app,
+                final_state,
+            )
+            if final_state not in abci_app_transition_mapping:
+                # no linkage defined
+                paths.append([element])
+                continue
+            next_initial_state = abci_app_transition_mapping[final_state]
+            next_app = initial_state_to_app[next_initial_state]
+            if next_app in previous_apps_:
+                # self-loops do not require attention
+                # we don't append to path
+                continue
+            new_previous_apps = previous_apps_ + [app]
+            for path in get_paths(next_initial_state, next_app, new_previous_apps):
+                # if element not in path:
+                paths.append([element] + path)
+        return paths if paths != [] else default
+
+    all_paths: List[
+        List[Tuple[AppState, Type[AbciApp], Optional[AppState]]]
+    ] = get_paths(abci_apps[0].initial_round_cls, abci_apps[0])
+    new_db_post_conditions: Dict[AppState, List[str]] = {}
+    for path in all_paths:
+        current_initial_state, current_app, current_final_state = path[0]
+        accumulated_post_conditions: Set[str] = set(
+            current_app.db_pre_conditions.get(current_initial_state, [])
+        )
+        for (next_initial_state, next_app, next_final_state) in path[1:]:
+            if current_final_state is None:
+                # No outwards transition, nothing to check.
+                # we are at the end of a path where the last
+                # app has no final state and therefore no post conditions
+                break
+            accumulated_post_conditions = accumulated_post_conditions.union(
+                set(current_app.db_post_conditions[current_final_state])
+            )
+            # we now check that the pre conditions of the next app
+            # are compatible with the post conditions of the current apps.
+            if next_initial_state in next_app.db_pre_conditions:
+                diff = set.difference(
+                    set(next_app.db_pre_conditions[next_initial_state]),
+                    accumulated_post_conditions,
+                )
+                if len(diff) != 0:
+                    raise ValueError(
+                        f"Pre conditions '{diff}' of app '{next_app}' not a post condition of app '{current_app}' or any preceding app in path {path}."
+                    )
+            else:
+                raise ValueError(
+                    f"No pre-conditions have been set for {next_initial_state}! "
+                    f"You need to explicitly specify them as empty if there are no pre-conditions for this FSM."
+                )
+            current_app = next_app
+            current_final_state = next_final_state
+
+        if current_final_state is not None:
+            new_db_post_conditions[current_final_state] = list(
+                accumulated_post_conditions
+            )
+
     # Warn about events duplicated in multiple apps
     app_to_events = {app: app.get_all_events() for app in abci_apps}
     all_events = set.union(*app_to_events.values())
@@ -120,8 +218,11 @@ def chain(  # pylint: disable=too-many-locals
                 " If this is not the intented behaviour, please rename it to enforce its uniqueness."
             )
 
-    # Merge the transition functions, final states and events
     new_initial_round_cls = abci_apps[0].initial_round_cls
+    new_initial_states = abci_apps[0].initial_states
+    new_db_pre_conditions = abci_apps[0].db_pre_conditions
+
+    # Merge the transition functions, final states and events
     potential_final_states = set.union(*(app.final_states for app in abci_apps))
     potential_events_to_timeout: EventToTimeout = {}
     for app in abci_apps:
@@ -172,15 +273,19 @@ def chain(  # pylint: disable=too-many-locals
     new_cross_period_persisted_keys = []
     for app in abci_apps:
         new_cross_period_persisted_keys.extend(app.cross_period_persisted_keys)
+    new_cross_period_persisted_keys = list(set(new_cross_period_persisted_keys))
 
     # Return the composed result
     class ComposedAbciApp(AbciApp[EventType]):
         """Composed abci app class."""
 
         initial_round_cls: AppState = new_initial_round_cls
+        initial_states: Set[AppState] = new_initial_states
         transition_function: AbciAppTransitionFunction = new_transition_function
         final_states: Set[AppState] = new_final_states
         event_to_timeout: EventToTimeout = new_events_to_timeout
         cross_period_persisted_keys: List[str] = new_cross_period_persisted_keys
+        db_pre_conditions: Dict[AppState, List[str]] = new_db_pre_conditions
+        db_post_conditions: Dict[AppState, List[str]] = new_db_post_conditions
 
     return ComposedAbciApp
