@@ -33,11 +33,15 @@ from packages.valory.protocols.http.message import HttpMessage
 from packages.valory.skills.abstract_round_abci.base import (
     AbciApp,
     AbciAppDB,
+    AbstractRound,
     BaseSynchronizedData,
     ConsensusParams,
+    RESET_INDEX_DEFAULT,
+    ROUND_COUNT_DEFAULT,
     RoundSequence,
 )
 from packages.valory.skills.abstract_round_abci.utils import (
+    DEFAULT_TENDERMINT_P2P_URL,
     get_data_from_nested_dict,
     get_value_with_type,
 )
@@ -118,6 +122,9 @@ class BaseParams(Model):  # pylint: disable=too-many-instance-attributes
         self.share_tm_config_on_startup = kwargs.pop(
             "share_tm_config_on_startup", False
         )
+        self.tendermint_p2p_url = kwargs.pop(
+            "tendermint_p2p_url", DEFAULT_TENDERMINT_P2P_URL
+        )
         setup_params = kwargs.pop("setup", {})
         # we sanitize for null values as these are just kept for schema definitions
         setup_params = {
@@ -148,7 +155,9 @@ class SharedState(Model):
         self.abci_app_cls = self._process_abci_app_cls(abci_app_cls)
         self.abci_app_cls._is_abstract = skill_context.is_abstract_component
         self._round_sequence: Optional[RoundSequence] = None
-        self.last_reset_params: Optional[List[Tuple[str, str]]] = None
+        self.tm_recovery_params: TendermintRecoveryParams = TendermintRecoveryParams(
+            self.abci_app_cls.initial_round_cls
+        )
         kwargs["skill_context"] = skill_context
         super().__init__(*args, **kwargs)
 
@@ -242,6 +251,16 @@ class RetriesInfo:
         return self.backoff_factor ** self.retries_attempted
 
 
+@dataclass
+class TendermintRecoveryParams:
+    """A dataclass to hold all parameters related to agent <-> tendermint recovery procedures."""
+
+    reset_from_round: Type[AbstractRound]
+    round_count: int = ROUND_COUNT_DEFAULT
+    reset_index: int = RESET_INDEX_DEFAULT
+    reset_params: Optional[List[Tuple[str, str]]] = None
+
+
 class ApiSpecs(Model):
     """A model that wraps APIs to get cryptocurrency prices."""
 
