@@ -20,10 +20,10 @@
 """ABCI App test tools."""
 
 
+from enum import Enum
 from typing import Dict, Tuple, Type, Union
 from unittest.mock import MagicMock
 
-from packages.valory.protocols.abci.custom_types import Events
 from packages.valory.skills.abstract_round_abci.base import (
     AbciApp,
     AbstractRound,
@@ -47,7 +47,6 @@ class _ConcreteRound(AbstractRound):
 class ConcreteRoundA(_ConcreteRound):
     """Dummy instantiation of the AbstractRound class."""
 
-    round_id = "concrete_a"
     allowed_tx_type = "payload_a"
 
     def end_block(self) -> Tuple[MagicMock, MagicMock]:
@@ -58,88 +57,98 @@ class ConcreteRoundA(_ConcreteRound):
 class ConcreteRoundB(_ConcreteRound):
     """Dummy instantiation of the AbstractRound class."""
 
-    round_id = "concrete_b"
     allowed_tx_type = "payload_b"
 
 
 class ConcreteRoundC(_ConcreteRound):
     """Dummy instantiation of the AbstractRound class."""
 
-    round_id = "concrete_c"
     allowed_tx_type = "payload_c"
 
 
 class ConcreteBackgroundRound(_ConcreteRound):
     """Dummy instantiation of the AbstractRound class."""
 
-    round_id = "concrete_background"
     allowed_tx_type = "payload_background_c"
 
 
 class ConcreteTerminationRoundA(_ConcreteRound):
     """Dummy instantiation of the AbstractRound class."""
 
-    round_id = "concrete_termination_a"
     allowed_tx_type = "payload_termination_a"
 
-    def end_block(self) -> Tuple[MagicMock, MagicMock]:
-        """End block."""
-        return MagicMock(), MagicMock()
-
 
 class ConcreteTerminationRoundB(_ConcreteRound):
     """Dummy instantiation of the AbstractRound class."""
 
-    round_id = "concrete_termination_b"
     allowed_tx_type = "payload_termination_b"
 
 
 class ConcreteTerminationRoundC(_ConcreteRound):
     """Dummy instantiation of the AbstractRound class."""
 
-    round_id = "concrete_termination_c"
     allowed_tx_type = "payload_termination_c"
 
 
-class ConcreteEvents(Events):
+class ConcreteEvents(Enum):
     """Defines dummy events to be used for testing purposes."""
 
     TERMINATE = "terminate"
+    A = "a"
+    B = "b"
+    C = "c"
+    TIMEOUT = "timeout"
+
+    def __str__(self) -> str:
+        """Get the string representation of the event."""
+        return self.value
 
 
-class AbciAppTest(AbciApp[str]):
+class AbciAppTest(AbciApp[ConcreteEvents]):
     """A dummy AbciApp for testing purposes."""
 
     TIMEOUT: float = 1.0
 
     initial_round_cls: Type[AbstractRound] = ConcreteRoundA
-    transition_function: Dict[Type[AbstractRound], Dict[str, Type[AbstractRound]]] = {
-        ConcreteRoundA: {"a": ConcreteRoundA, "b": ConcreteRoundB, "c": ConcreteRoundC},
-        ConcreteRoundB: {"b": ConcreteRoundB, "timeout": ConcreteRoundA},
-        ConcreteRoundC: {"c": ConcreteRoundA, "timeout": ConcreteRoundC},
+    transition_function: Dict[
+        Type[AbstractRound], Dict[ConcreteEvents, Type[AbstractRound]]
+    ] = {
+        ConcreteRoundA: {
+            ConcreteEvents.A: ConcreteRoundA,
+            ConcreteEvents.B: ConcreteRoundB,
+            ConcreteEvents.C: ConcreteRoundC,
+        },
+        ConcreteRoundB: {
+            ConcreteEvents.B: ConcreteRoundB,
+            ConcreteEvents.TIMEOUT: ConcreteRoundA,
+        },
+        ConcreteRoundC: {
+            ConcreteEvents.C: ConcreteRoundA,
+            ConcreteEvents.TIMEOUT: ConcreteRoundC,
+        },
     }
     background_round_cls = ConcreteBackgroundRound
     termination_transition_function: Dict[
-        Type[AbstractRound], Dict[str, Type[AbstractRound]]
+        Type[AbstractRound], Dict[ConcreteEvents, Type[AbstractRound]]
     ] = {
         ConcreteBackgroundRound: {
             ConcreteEvents.TERMINATE: ConcreteTerminationRoundA,
         },
         ConcreteTerminationRoundA: {
-            "a": ConcreteTerminationRoundA,
-            "b": ConcreteTerminationRoundB,
-            "c": ConcreteTerminationRoundC,
+            ConcreteEvents.A: ConcreteTerminationRoundA,
+            ConcreteEvents.B: ConcreteTerminationRoundB,
+            ConcreteEvents.C: ConcreteTerminationRoundC,
         },
         ConcreteTerminationRoundB: {
-            "b": ConcreteTerminationRoundB,
-            "timeout": ConcreteTerminationRoundA,
+            ConcreteEvents.B: ConcreteTerminationRoundB,
+            ConcreteEvents.TIMEOUT: ConcreteTerminationRoundA,
         },
         ConcreteTerminationRoundC: {
-            "c": ConcreteTerminationRoundA,
-            "timeout": ConcreteTerminationRoundC,
+            ConcreteEvents.C: ConcreteTerminationRoundA,
+            ConcreteEvents.TIMEOUT: ConcreteTerminationRoundC,
         },
     }
     termination_event = ConcreteEvents.TERMINATE
-    event_to_timeout: Dict[str, float] = {
-        "timeout": TIMEOUT,
+    event_to_timeout: Dict[ConcreteEvents, float] = {
+        ConcreteEvents.TIMEOUT: TIMEOUT,
     }
