@@ -132,7 +132,7 @@ class FSMBehaviourBaseCase(BaseSkillTestCase):
         self._skill.skill_context.benchmark_tool.log_dir = Path(self.benchmark_dir.name)
         assert (  # nosec
             cast(BaseBehaviour, self.behaviour.current_behaviour).behaviour_id
-            == self.behaviour.initial_behaviour_cls.behaviour_id
+            == self.behaviour.initial_behaviour_cls.auto_behaviour_id()
         )
 
     def fast_forward_to_behaviour(
@@ -142,10 +142,12 @@ class FSMBehaviourBaseCase(BaseSkillTestCase):
         synchronized_data: BaseSynchronizedData,
     ) -> None:
         """Fast forward the FSM to a behaviour."""
-        next_behaviour = {s.behaviour_id: s for s in behaviour.behaviours}[behaviour_id]
+        next_behaviour = {s.auto_behaviour_id(): s for s in behaviour.behaviours}[
+            behaviour_id
+        ]
         next_behaviour = cast(Type[BaseBehaviour], next_behaviour)
         behaviour.current_behaviour = next_behaviour(
-            name=next_behaviour.behaviour_id, skill_context=behaviour.context
+            name=next_behaviour.auto_behaviour_id(), skill_context=behaviour.context
         )
         self.skill.skill_context.state.round_sequence.abci_app._round_results.append(
             synchronized_data
@@ -154,6 +156,9 @@ class FSMBehaviourBaseCase(BaseSkillTestCase):
         self.skill.skill_context.behaviours.main._last_round_height = (
             self.skill.skill_context.state.round_sequence.abci_app.current_round_height
         )
+        self.skill.skill_context.state.round_sequence.abci_app._current_round_cls = (
+            next_behaviour.matching_round
+        )
         self.skill.skill_context.state.round_sequence.abci_app._current_round = (
             next_behaviour.matching_round(
                 synchronized_data, self.skill.skill_context.params.consensus_params
@@ -381,7 +386,7 @@ class FSMBehaviourBaseCase(BaseSkillTestCase):
         ) as mock_round_sequence:
             mock_round_sequence.last_round_id = cast(
                 AbstractRound, current_behaviour.matching_round
-            ).round_id
+            ).auto_round_id()
             current_behaviour.act_wrapper()
             assert current_behaviour.is_done()  # nosec
 
