@@ -146,6 +146,23 @@ class BehaviourB(BaseBehaviour):
         yield
 
 
+class BehaviourC(BaseBehaviour):
+    """Dummy behaviour."""
+
+    def async_act(self) -> Generator:
+        """Dummy act method."""
+        yield
+
+
+def test_auto_behaviour_id() -> None:
+    """Test that the 'auto_behaviour_id()' method works as expected."""
+
+    assert BehaviourB.auto_behaviour_id() == BEHAVIOUR_B_ID
+    assert BehaviourB.behaviour_id == BEHAVIOUR_B_ID
+    assert BehaviourC.auto_behaviour_id() == "behaviour_c"
+    assert isinstance(BehaviourC.behaviour_id, property)
+
+
 class ConcreteBackgroundBehaviour(BaseBehaviour):
     """Dummy behaviour."""
 
@@ -208,7 +225,9 @@ class TestAbstractRoundBehaviour:
 
     def test_check_matching_round_consistency(self) -> None:
         """Test classmethod '_get_behaviour_id_to_behaviour_mapping', negative case."""
-        rounds = [MagicMock(round_id=f"round_{i}") for i in range(3)]
+        rounds = [
+            MagicMock(**{"auto_round_id.return_value": f"round_{i}"}) for i in range(3)
+        ]
         mock_behaviours = [
             MagicMock(matching_round=round, behaviour_id=f"behaviour_{i}")
             for i, round in enumerate(rounds)
@@ -240,8 +259,8 @@ class TestAbstractRoundBehaviour:
     def test_get_behaviour_id_to_behaviour_mapping_negative(self) -> None:
         """Test classmethod '_get_behaviour_id_to_behaviour_mapping', negative case."""
         behaviour_id = "behaviour_id"
-        behaviour_1 = MagicMock(behaviour_id=behaviour_id)
-        behaviour_2 = MagicMock(behaviour_id=behaviour_id)
+        behaviour_1 = MagicMock(**{"auto_behaviour_id.return_value": behaviour_id})
+        behaviour_2 = MagicMock(**{"auto_behaviour_id.return_value": behaviour_id})
 
         with pytest.raises(
             ValueError,
@@ -261,13 +280,19 @@ class TestAbstractRoundBehaviour:
         behaviour_id_1 = "behaviour_id_1"
         behaviour_id_2 = "behaviour_id_2"
         round_cls = RoundA
-        round_id = round_cls.round_id
-        behaviour_1 = MagicMock(behaviour_id=behaviour_id_1, matching_round=round_cls)
-        behaviour_2 = MagicMock(behaviour_id=behaviour_id_2, matching_round=round_cls)
+        round_id = round_cls.auto_round_id()
+        behaviour_1 = MagicMock(
+            matching_round=round_cls,
+            **{"auto_behaviour_id.return_value": behaviour_id_1},
+        )
+        behaviour_2 = MagicMock(
+            matching_round=round_cls,
+            **{"auto_behaviour_id.return_value": behaviour_id_2},
+        )
 
         with pytest.raises(
             ValueError,
-            match=f"the behaviours '{behaviour_id_2}' and '{behaviour_id_1}' point to the same matching round '{round_id}'",
+            match=f"the behaviours '{behaviour_2.auto_behaviour_id()}' and '{behaviour_1.auto_behaviour_id()}' point to the same matching round '{round_id}'",
         ):
             with mock.patch.object(_MetaRoundBehaviour, "_check_consistency"):
 
@@ -312,7 +337,10 @@ class TestAbstractRoundBehaviour:
         behaviour = MyRoundBehaviour(name=MagicMock(), skill_context=MagicMock())
         final_behaviour = behaviour._round_to_behaviour[FinalRound]
         assert issubclass(final_behaviour, DegenerateBehaviour)
-        assert final_behaviour.behaviour_id == f"degenerate_{FinalRound.round_id}"
+        assert (
+            final_behaviour.auto_behaviour_id()
+            == f"degenerate_behaviour_{FinalRound.auto_round_id()}"
+        )
 
     def test_check_behaviour_id_uniqueness_negative(self) -> None:
         """Test metaclass method '_check_consistency', negative case."""
@@ -320,10 +348,12 @@ class TestAbstractRoundBehaviour:
         behaviour_1_cls_name = "Behaviour1"
         behaviour_2_cls_name = "Behaviour2"
         behaviour_1 = MagicMock(
-            behaviour_id=behaviour_id, __name__=behaviour_1_cls_name
+            __name__=behaviour_1_cls_name,
+            **{"auto_behaviour_id.return_value": behaviour_id},
         )
         behaviour_2 = MagicMock(
-            behaviour_id=behaviour_id, __name__=behaviour_2_cls_name
+            __name__=behaviour_2_cls_name,
+            **{"auto_behaviour_id.return_value": behaviour_id},
         )
 
         with pytest.raises(
@@ -341,9 +371,15 @@ class TestAbstractRoundBehaviour:
         behaviour_id_1 = "behaviour_id_1"
         behaviour_id_2 = "behaviour_id_2"
         round_cls = RoundA
-        round_id = round_cls.round_id
-        behaviour_1 = MagicMock(behaviour_id=behaviour_id_1, matching_round=round_cls)
-        behaviour_2 = MagicMock(behaviour_id=behaviour_id_2, matching_round=round_cls)
+        round_id = round_cls.auto_round_id()
+        behaviour_1 = MagicMock(
+            matching_round=round_cls,
+            **{"auto_behaviour_id.return_value": "behaviour_id_1"},
+        )
+        behaviour_2 = MagicMock(
+            matching_round=round_cls,
+            **{"auto_behaviour_id.return_value": "behaviour_id_2"},
+        )
 
         with pytest.raises(
             ABCIAppInternalError,
@@ -358,15 +394,17 @@ class TestAbstractRoundBehaviour:
     def test_check_initial_behaviour_in_set_of_behaviours_negative_case(self) -> None:
         """Test classmethod '_check_initial_behaviour_in_set_of_behaviours' when initial behaviour is NOT in the set."""
         behaviour_1 = MagicMock(
-            behaviour_id="behaviour_id_1", matching_round=MagicMock()
+            matching_round=MagicMock(),
+            **{"auto_behaviour_id.return_value": "behaviour_id_1"},
         )
         behaviour_2 = MagicMock(
-            behaviour_id="behaviour_id_2", matching_round=MagicMock()
+            matching_round=MagicMock(),
+            **{"auto_behaviour_id.return_value": "behaviour_id_2"},
         )
 
         with pytest.raises(
             ABCIAppInternalError,
-            match="initial behaviour behaviour_id_2 is not in the set of behaviours",
+            match=f"initial behaviour {behaviour_2.auto_behaviour_id()} is not in the set of behaviours",
         ):
 
             class MyRoundBehaviour(AbstractRoundBehaviour):
@@ -648,7 +686,9 @@ def test_reset_should_be_performed_when_tm_unhealthy() -> None:
         return None
         yield
 
-    def dummy_reset_tendermint_with_wait() -> Generator[None, None, bool]:
+    def dummy_reset_tendermint_with_wait(
+        is_recovery: bool = False,
+    ) -> Generator[None, None, bool]:
         """A dummy method for reset_tendermint_with_wait."""
         # we assume the reset goes through successfully
         return True
