@@ -19,18 +19,13 @@
 
 """Test the behaviours_utils.py module of the skill."""
 
-# pylint: skip-file
-
 import json
 import logging
 import math
 import platform
-import shutil
-import sys
 import time
 from abc import ABC
 from collections import OrderedDict
-from contextlib import suppress
 from datetime import datetime
 from enum import Enum
 from pathlib import Path
@@ -51,25 +46,23 @@ from unittest.mock import MagicMock
 
 import pytest
 import pytz  # type: ignore  # pylint: disable=import-error
-from hypothesis import given
-from hypothesis import strategies as st
-
-from packages.valory.protocols.ledger_api.custom_types import (
-    SignedTransaction,
-    TransactionDigest,
-)
-
-
-try:
-    import atheris  # type: ignore
-except (ImportError, ModuleNotFoundError):
-    atheris: Any = None  # type: ignore
+from _pytest.logging import LogCaptureFixture
 
+# pylint: skip-file
+from aea.common import JSONLike
+from aea.protocols.base import Message
+from aea.test_tools.utils import as_context
 from aea_test_autonomy.helpers.base import try_send
+from hypothesis import given, settings
+from hypothesis import strategies as st
 
 from packages.open_aea.protocols.signing import SigningMessage
 from packages.valory.connections.http_client.connection import HttpDialogues
 from packages.valory.protocols.http import HttpMessage
+from packages.valory.protocols.ledger_api.custom_types import (
+    SignedTransaction,
+    TransactionDigest,
+)
 from packages.valory.protocols.ledger_api.message import LedgerApiMessage
 from packages.valory.skills.abstract_round_abci import behaviour_utils
 from packages.valory.skills.abstract_round_abci.base import (
@@ -94,13 +87,22 @@ from packages.valory.skills.abstract_round_abci.behaviour_utils import (
     TmManager,
     make_degenerate_behaviour,
 )
+from packages.valory.skills.abstract_round_abci.io_.ipfs import (
+    IPFSInteract,
+    IPFSInteractionError,
+)
 from packages.valory.skills.abstract_round_abci.models import (
     SharedState,
+    TendermintRecoveryParams,
     _DEFAULT_REQUEST_RETRY_DELAY,
     _DEFAULT_REQUEST_TIMEOUT,
     _DEFAULT_TX_MAX_ATTEMPTS,
     _DEFAULT_TX_TIMEOUT,
 )
+from packages.valory.skills.abstract_round_abci.tests.conftest import profile_name
+
+
+settings.load_profile(profile_name)
 
 
 PACKAGE_DIR = Path(__file__).parent.parent
@@ -114,14 +116,17 @@ MIN_DATETIME_WINDOWS = datetime(1970, 1, 3, 1, 0, 0)
 MAX_DATETIME_WINDOWS = datetime(3000, 12, 30, 23, 59, 59)
 
 
-@pytest.fixture(scope="session", autouse=True)
-def hypothesis_cleanup() -> Generator:
-    """Fixture to remove hypothesis directory after tests."""
-    yield
-    hypothesis_dir = PACKAGE_DIR / ".hypothesis"
-    if hypothesis_dir.exists():
-        with suppress(OSError, PermissionError):
-            shutil.rmtree(hypothesis_dir)
+def mock_yield_and_return(
+    return_value: Any,
+) -> Callable[[], Generator[None, None, Any]]:
+    """Wrapper for a Dummy generator that returns a `bool`."""
+
+    def yield_and_return(*_: Any, **__: Any) -> Generator[None, None, Any]:
+        """Dummy generator that returns a `bool`."""
+        yield
+        return return_value
+
+    return yield_and_return
 
 
 def yield_and_return_bool_wrapper(
@@ -515,12 +520,63 @@ class TestBaseBehaviour:
         self.context_mock.state.synchronized_data = (
             self.context_state_synchronized_data_mock
         )
+        self.current_round_count = 10
+        self.current_reset_index = 10
+        self.context_mock.state.synchronized_data.db = MagicMock(
+            round_count=self.current_round_count, reset_index=self.current_reset_index
+        )
         self.context_mock.state.round_sequence.current_round_id = "round_a"
         self.context_mock.state.round_sequence.syncing_up = False
         self.context_mock.state.round_sequence.block_stall_deadline_expired = False
         self.context_mock.http_dialogues = HttpDialogues()
         self.context_mock.handlers.__dict__ = {"http": MagicMock()}
         self.behaviour = BehaviourATest(name="", skill_context=self.context_mock)
+        self.behaviour.context.logger = logging  # type: ignore
+
+    def test_send_to_ipfs(self, caplog: LogCaptureFixture) -> None:
+        """Test send_to_ipfs"""
+
+        assert self.behaviour.ipfs_enabled is False
+        expected = "Trying to perform an IPFS operation, but IPFS has not been enabled!"
+        with pytest.raises(ValueError, match=expected):
+            self.behaviour.send_to_ipfs("filepath", [])
+
+        self.behaviour.ipfs_enabled = True
+        self.behaviour._ipfs_interact = IPFSInteract(None)  # type: ignore
+        with mock.patch.object(
+            IPFSInteract, "store_and_send", return_value="mock_hash"
+        ):
+            with caplog.at_level(logging.INFO):
+                self.behaviour.send_to_ipfs("filepath", [])
+                assert "IPFS hash is: mock_hash" in caplog.text
+
+        side_effect = IPFSInteractionError
+        with mock.patch.object(IPFSInteract, "store_and_send", side_effect=side_effect):
+            with caplog.at_level(logging.ERROR):
+                self.behaviour.send_to_ipfs("filepath", [])
+                expected = "An error occurred while trying to send a file to IPFS:"
+                assert expected in caplog.text
+
+    def test_get_from_ipfs(self, caplog: LogCaptureFixture) -> None:
+        """Test get_from_ipfs"""
+
+        assert self.behaviour.ipfs_enabled is False
+        expected = "Trying to perform an IPFS operation, but IPFS has not been enabled!"
+        with pytest.raises(ValueError, match=expected):
+            self.behaviour.get_from_ipfs("mock_hash", "target_dir")
+
+        self.behaviour.ipfs_enabled = True
+        self.behaviour._ipfs_interact = IPFSInteract(None)  # type: ignore
+        with mock.patch.object(IPFSInteract, "get_and_read"):
+            with caplog.at_level(logging.INFO):
+                self.behaviour.get_from_ipfs("mock_hash", "target_dir")
+
+        side_effect = IPFSInteractionError
+        with mock.patch.object(IPFSInteract, "store_and_send", side_effect=side_effect):
+            with caplog.at_level(logging.ERROR):
+                self.behaviour.get_from_ipfs("mock_hash", "target_dir")
+                expected = "An error occurred while trying to fetch a file from IPFS:"
+                assert expected in caplog.text
 
     def test_params_property(self) -> None:
         """Test the 'params' property."""
@@ -669,7 +725,6 @@ class TestBaseBehaviour:
         self.behaviour.context.state.round_sequence.syncing_up = True
         self.behaviour.context.state.round_sequence.height = 0
         self.behaviour.matching_round = MagicMock()
-        self.behaviour.context.logger.info = lambda msg: logging.info(msg)  # type: ignore
 
         with mock.patch.object(logging, "info") as log_mock, mock.patch.object(
             BaseBehaviour,
@@ -699,7 +754,6 @@ class TestBaseBehaviour:
         self.behaviour.context.state.round_sequence.height = 0
         self.behaviour.context.params.tendermint_check_sleep_delay = 3
         self.behaviour.matching_round = MagicMock()
-        self.behaviour.context.logger.info = lambda msg: logging.info(msg)  # type: ignore
 
         gen = self.behaviour.async_act_wrapper()
         try_send(gen)
@@ -740,13 +794,13 @@ class TestBaseBehaviour:
         # assert that everything is pre-set correctly
         assert (
             self.behaviour.context.state.round_sequence.current_round_id
-            == self.behaviour.matching_round.round_id
+            == self.behaviour.matching_round.auto_round_id()
             == "round_a"
         )
 
         # create the exact same stop condition that we create in the `send_a2a_transaction` method
         stop_condition = self.behaviour.is_round_ended(
-            self.behaviour.matching_round.round_id
+            self.behaviour.matching_round.auto_round_id()
         )
         gen = self.behaviour._send_transaction(
             MagicMock(),
@@ -764,7 +818,7 @@ class TestBaseBehaviour:
         # assert that everything was set as expected
         assert (
             self.behaviour.context.state.round_sequence.current_round_id
-            != self.behaviour.matching_round.round_id
+            != self.behaviour.matching_round.auto_round_id()
             and self.behaviour.context.state.round_sequence.current_round_id == "test"
         )
         # assert that the stop condition now applies
@@ -1110,37 +1164,22 @@ class TestBaseBehaviour:
         ):
             self.behaviour._send_signing_request(b"")
 
-    @pytest.mark.skip
-    def test_fuzz_send_signing_request(self) -> None:
-        """Test '_send_signing_request'.
+    @given(st.binary())
+    def test_fuzz_send_signing_request(self, input_bytes: bytes) -> None:
+        """Fuzz '_send_signing_request'.
 
-        Do not run this test through pytest. Add the following lines at the bottom
-        of the file and run it as a script:
-        t = TestBaseBehaviour()
-        t.setup()
-        t.test_fuzz_send_signing_request()
+        Mock context manager decorators don't work here.
+
+        :param input_bytes: fuzz input
         """
-
-        @atheris.instrument_func
-        def fuzz_send_signing_request(input_bytes: bytes) -> None:
-            """Fuzz '_send_signing_request'.
-
-            Mock context manager decorators don't work here.
-
-            :param input_bytes: fuzz input
-            """
-            with mock.patch.object(
-                self.behaviour.context.signing_dialogues,
-                "create",
-                return_value=(MagicMock(), MagicMock()),
-            ):
-                with mock.patch.object(behaviour_utils, "RawMessage"):
-                    with mock.patch.object(behaviour_utils, "Terms"):
-                        self.behaviour._send_signing_request(input_bytes)
-
-        atheris.instrument_all()
-        atheris.Setup(sys.argv, fuzz_send_signing_request)
-        atheris.Fuzz()
+        with mock.patch.object(
+            self.behaviour.context.signing_dialogues,
+            "create",
+            return_value=(MagicMock(), MagicMock()),
+        ):
+            with mock.patch.object(behaviour_utils, "RawMessage"):
+                with mock.patch.object(behaviour_utils, "Terms"):
+                    self.behaviour._send_signing_request(input_bytes)
 
     @mock.patch.object(BaseBehaviour, "_get_request_nonce_from_dialogue")
     @mock.patch.object(behaviour_utils, "RawMessage")
@@ -1414,6 +1453,45 @@ class TestBaseBehaviour:
         assert tx_hash is None
         assert status == RPCResponseStatus.UNCLASSIFIED_ERROR
 
+    def test_get_transaction_receipt(self, caplog: LogCaptureFixture) -> None:
+        """Test get_transaction_receipt."""
+
+        expected: JSONLike = {"dummy": "tx_receipt"}
+        transaction_receipt = LedgerApiMessage.TransactionReceipt("", expected, {})
+        tx_receipt_message = LedgerApiMessage(
+            LedgerApiMessage.Performative.TRANSACTION_RECEIPT,  # type: ignore
+            transaction_receipt=transaction_receipt,
+        )
+        side_effect = mock_yield_and_return(tx_receipt_message)
+        with as_context(
+            mock.patch.object(self.behaviour, "_send_transaction_receipt_request"),
+            mock.patch.object(
+                self.behaviour, "wait_for_message", side_effect=side_effect
+            ),
+        ):
+            gen = self.behaviour.get_transaction_receipt("tx_digest")
+            try:
+                while True:
+                    next(gen)
+            except StopIteration as e:
+                assert e.value == expected
+
+    def test_get_transaction_receipt_error(self, caplog: LogCaptureFixture) -> None:
+        """Test get_transaction_receipt with error performative."""
+
+        error_message = LedgerApiMessage(LedgerApiMessage.Performative.ERROR, code=0)  # type: ignore
+        side_effect = mock_yield_and_return(error_message)
+        with as_context(
+            mock.patch.object(self.behaviour, "_send_transaction_receipt_request"),
+            mock.patch.object(
+                self.behaviour, "wait_for_message", side_effect=side_effect
+            ),
+        ):
+            gen = self.behaviour.get_transaction_receipt("tx_digest")
+            try_send(gen)
+            try_send(gen)
+            assert "Error when requesting transaction receipt" in caplog.text
+
     @pytest.mark.parametrize("contract_address", [None, "contract_address"])
     def test_get_contract_api_response(self, contract_address: Optional[str]) -> None:
         """Test 'get_contract_api_response'."""
@@ -1675,12 +1753,33 @@ class TestBaseBehaviour:
         BaseBehaviour, "_build_http_request_message", return_value=(None, None)
     )
     @pytest.mark.parametrize(
-        "reset_response, status_response, local_height, n_iter, expecting_success",
+        "reset_response, status_response, local_height, on_startup, n_iter, expecting_success",
         (
             (
                 {"message": "Tendermint reset was successful.", "status": True},
                 {"result": {"sync_info": {"latest_block_height": 1}}},
                 1,
+                False,
+                3,
+                True,
+            ),
+            (
+                {"message": "Tendermint reset was successful.", "status": True},
+                {"result": {"sync_info": {"latest_block_height": 1}}},
+                1,
+                True,
+                2,
+                True,
+            ),
+            (
+                {
+                    "message": "Tendermint reset was successful.",
+                    "status": True,
+                    "is_replay": True,
+                },
+                {"result": {"sync_info": {"latest_block_height": 1}}},
+                1,
+                False,
                 3,
                 True,
             ),
@@ -1688,6 +1787,7 @@ class TestBaseBehaviour:
                 {"message": "Tendermint reset was successful.", "status": True},
                 {"result": {"sync_info": {"latest_block_height": 1}}},
                 3,
+                False,
                 3,
                 False,
             ),
@@ -1695,14 +1795,16 @@ class TestBaseBehaviour:
                 {"message": "Error resetting tendermint.", "status": False},
                 {},
                 0,
+                False,
                 2,
                 False,
             ),
-            ("wrong_response", {}, 0, 2, False),
+            ("wrong_response", {}, 0, False, 2, False),
             (
                 {"message": "Reset Successful.", "status": True},
                 "not_accepting_txs_yet",
                 0,
+                False,
                 3,
                 False,
             ),
@@ -1715,6 +1817,7 @@ class TestBaseBehaviour:
         reset_response: Union[Dict[str, Union[bool, str]], str],
         status_response: Union[Dict[str, Union[int, str]], str],
         local_height: int,
+        on_startup: bool,
         n_iter: int,
         expecting_success: bool,
     ) -> None:
@@ -1749,7 +1852,7 @@ class TestBaseBehaviour:
             BaseBehaviour, "sleep", new_callable=lambda *_: self.dummy_sleep
         ):
             self.behaviour.context.state.round_sequence.height = local_height
-            reset = self.behaviour.reset_tendermint_with_wait()
+            reset = self.behaviour.reset_tendermint_with_wait(on_startup=on_startup)
             for _ in range(n_iter):
                 next(reset)
             offset = math.ceil(
@@ -1767,10 +1870,15 @@ class TestBaseBehaviour:
                 "%Y-%m-%dT%H:%M:%S.%fZ"
             )
 
-            expected_parameters = [
-                ("genesis_time", genesis_time),
-                ("initial_height", initial_height),
-            ]
+            expected_parameters = (
+                [
+                    ("genesis_time", genesis_time),
+                    ("initial_height", initial_height),
+                ]
+                if not on_startup
+                else None
+            )
+
             build_http_request_message_mock.assert_called_with(
                 "GET",
                 self.behaviour.context.params.tendermint_com_url + "/hard_reset",
@@ -1786,39 +1894,33 @@ class TestBaseBehaviour:
                     # reset to be stored in the shared state, as they could be used
                     # later for performing hard reset in cases when the agent <-> tendermint
                     # communication is broken
+                    shared_state = cast(SharedState, self.behaviour.context.state)
+                    tm_recovery_params = shared_state.tm_recovery_params
+                    assert tm_recovery_params.reset_params == expected_parameters
                     assert (
-                        cast(
-                            SharedState, self.behaviour.context.state
-                        ).last_reset_params
-                        == expected_parameters
+                        tm_recovery_params.round_count
+                        == shared_state.synchronized_data.db.round_count - 1
+                    )
+                    assert (
+                        tm_recovery_params.reset_index
+                        == shared_state.round_sequence.abci_app.reset_index - 1
+                    )
+                    assert (
+                        tm_recovery_params.reset_from_round
+                        == self.behaviour.matching_round
                     )
             else:
                 pytest.fail("`reset_tendermint_with_wait` did not finish!")
 
-    @pytest.mark.skip
-    def test_fuzz_submit_tx(self) -> None:
-        """Test '_submit_tx'.
+    @given(st.binary())
+    def test_fuzz_submit_tx(self, input_bytes: bytes) -> None:
+        """Fuzz '_submit_tx'.
 
-        Do not run this test through pytest. Add the following lines at the bottom
-        of the file and run it as a script:
-        t = TestBaseBehaviour()
-        t.setup()
-        t.test_fuzz_submit_tx()
+        Mock context manager decorators don't work here.
+
+        :param input_bytes: fuzz input
         """
-
-        @atheris.instrument_func
-        def fuzz_submit_tx(input_bytes: bytes) -> None:
-            """Fuzz '_submit_tx'.
-
-            Mock context manager decorators don't work here.
-
-            :param input_bytes: fuzz input
-            """
-            self.behaviour._submit_tx(input_bytes)
-
-        atheris.instrument_all()
-        atheris.Setup(sys.argv, fuzz_submit_tx)
-        atheris.Fuzz()
+        self.behaviour._submit_tx(input_bytes)
 
 
 def test_degenerate_behaviour_async_act() -> None:
@@ -1836,7 +1938,7 @@ def test_degenerate_behaviour_async_act() -> None:
     context.state.round_sequence.syncing_up = False
     context.state.round_sequence.block_stall_deadline_expired = False
     behaviour = ConcreteDegenerateBehaviour(
-        name=ConcreteDegenerateBehaviour.behaviour_id, skill_context=context
+        name=ConcreteDegenerateBehaviour.auto_behaviour_id(), skill_context=context
     )
     with pytest.raises(
         SystemExit,
@@ -1852,7 +1954,7 @@ def test_make_degenerate_behaviour() -> None:
     assert isinstance(new_cls, type)
     assert issubclass(new_cls, DegenerateBehaviour)
 
-    assert new_cls.behaviour_id == f"degenerate_{round_id}"
+    assert new_cls.auto_behaviour_id() == f"degenerate_behaviour_{round_id}"
 
 
 class TestTmManager:
@@ -1878,13 +1980,15 @@ class TestTmManager:
         self.context_mock.state.synchronized_data = (
             self.context_state_synchronized_data_mock
         )
-        self.context_mock.state.last_reset_params = None
+        self.recovery_params = TendermintRecoveryParams(MagicMock())
+        self.context_mock.state.tm_recovery_params = self.recovery_params
         self.context_mock.state.round_sequence.current_round_id = "round_a"
         self.context_mock.state.round_sequence.syncing_up = False
         self.context_mock.state.round_sequence.block_stall_deadline_expired = False
         self.context_mock.http_dialogues = HttpDialogues()
         self.context_mock.handlers.__dict__ = {"http": MagicMock()}
         self.tm_manager = TmManager(name="", skill_context=self.context_mock)
+        self.tm_manager._max_reset_retry = 1
 
     def test_async_act(self) -> None:
         """Test the async_act method of the TmManager."""
@@ -1908,6 +2012,12 @@ class TestTmManager:
         num_active_peers: Optional[int],
     ) -> None:
         """Test _handle_unhealthy_tm."""
+
+        def mock_sleep(_seconds: int) -> Generator:
+            """A method that mocks sleep."""
+            return
+            yield
+
         gen = self.tm_manager._handle_unhealthy_tm()
         with mock.patch.object(
             self.tm_manager,
@@ -1917,6 +2027,8 @@ class TestTmManager:
             self.tm_manager,
             "num_active_peers",
             side_effect=yield_and_return_int_wrapper(num_active_peers),
+        ), mock.patch.object(
+            self.tm_manager, "sleep", side_effect=mock_sleep
         ), mock.patch(
             "sys.exit"
         ) as mock_sys_exit:
@@ -1944,7 +2056,7 @@ class TestTmManager:
     ) -> None:
         """Test that reset params returns the correct params."""
         if expected_reset_params is not None:
-            self.context_mock.state.last_reset_params = expected_reset_params
+            self.recovery_params.reset_params = expected_reset_params
         actual_reset_params = self.tm_manager._get_reset_params(False)
         assert expected_reset_params == actual_reset_params
 
@@ -1958,12 +2070,32 @@ class TestTmManager:
         actual = self.tm_manager.hard_reset_sleep
         assert actual == expected
 
-    def test_try_fix(self) -> None:
+    @pytest.mark.parametrize(
+        ("state", "notified", "message", "num_iter"),
+        [
+            (AsyncBehaviour.AsyncState.READY, False, None, 1),
+            (AsyncBehaviour.AsyncState.WAITING_MESSAGE, True, Message(), 2),
+            (AsyncBehaviour.AsyncState.WAITING_MESSAGE, True, Message(), 1),
+        ],
+    )
+    def test_try_fix(
+        self,
+        state: AsyncBehaviour.AsyncState,
+        notified: bool,
+        message: Optional[Message],
+        num_iter: int,
+    ) -> None:
         """Tests try_fix."""
 
         def mock_handle_unhealthy_tm() -> Generator:
             """A mock implementation of _handle_unhealthy_tm."""
-            yield
+            for _ in range(num_iter):
+                msg = yield
+                if msg is not None:
+                    # if a message is recieved, the state of the behviour should be "RUNNING"
+                    self.tm_manager._AsyncBehaviour__state = (
+                        AsyncBehaviour.AsyncState.RUNNING
+                    )
             return
 
         with mock.patch.object(
@@ -1971,17 +2103,38 @@ class TestTmManager:
             "_handle_unhealthy_tm",
             side_effect=mock_handle_unhealthy_tm,
         ):
-            # there is no active generator in the begging
+            # there is no active generator in the beginning
             assert not self.tm_manager.is_acting
 
             # a generator should be created, and be active
             self.tm_manager.try_fix()
             assert self.tm_manager.is_acting
 
+            # a message may (or may not) arrive
+            self.tm_manager._AsyncBehaviour__notified = notified
+            self.tm_manager._AsyncBehaviour__state = state
+            self.tm_manager._AsyncBehaviour__message = message
+
             # the generator has a single yield statement,
             # a second try_fix() call should finish it
-            self.tm_manager.try_fix()
-            assert not self.tm_manager.is_acting
+            for _ in range(num_iter):
+                self.tm_manager.try_fix()
+            assert not self.tm_manager.is_acting, num_iter
+
+    @pytest.mark.parametrize(
+        "state",
+        [
+            AsyncBehaviour.AsyncState.WAITING_MESSAGE,
+            AsyncBehaviour.AsyncState.READY,
+        ],
+    )
+    def test_get_callback_request(self, state: AsyncBehaviour.AsyncState) -> None:
+        """Tests get_callback_request."""
+        self.tm_manager._AsyncBehaviour__state = state
+        dummy_msg, dummy_behaviour = MagicMock(), MagicMock()
+        callback_req = self.tm_manager.get_callback_request()
+        with mock.patch.object(self.tm_manager, "try_send"):
+            callback_req(dummy_msg, dummy_behaviour)
 
     def test_is_acting(self) -> None:
         """Test is_acting."""
