@@ -38,6 +38,8 @@ from packages.valory.skills.abstract_round_abci.base import (
     AbciApp,
     AbstractRound,
     BaseSynchronizedData,
+    RESET_INDEX_DEFAULT,
+    ROUND_COUNT_DEFAULT,
 )
 from packages.valory.skills.abstract_round_abci.models import (
     ApiSpecs,
@@ -379,13 +381,19 @@ class TestSharedState:
 
         SharedState._process_abci_app_cls(AbciAppTest)
 
-    def test_last_reset_params_on_init(self) -> None:
-        """Test that `last_reset_params` gets initialized correctly."""
-        # by default `last_reset_params` should be None
+    def test_recovery_params_on_init(self) -> None:
+        """Test that `tm_recovery_params` get initialized correctly."""
         shared_state = SharedState(
             abci_app_cls=AbciAppTest, name="", skill_context=MagicMock()
         )
-        assert shared_state.last_reset_params is None
+        assert shared_state.tm_recovery_params is not None
+        assert shared_state.tm_recovery_params.round_count == ROUND_COUNT_DEFAULT
+        assert shared_state.tm_recovery_params.reset_index == RESET_INDEX_DEFAULT
+        assert (
+            shared_state.tm_recovery_params.reset_from_round
+            == AbciAppTest.initial_round_cls
+        )
+        assert shared_state.tm_recovery_params.reset_params is None
 
     def test_set_last_reset_params(self) -> None:
         """Test that `last_reset_params` get set correctly."""
