@@ -26,9 +26,11 @@ from packages.valory.skills.abstract_round_abci.base import (
     AbciApp,
     AbciAppTransitionFunction,
     AbstractRound,
+    AppState,
     BaseSynchronizedData,
     CollectDifferentUntilAllRound,
     CollectSameUntilThresholdRound,
+    get_name,
 )
 from packages.valory.skills.hello_world_abci.payloads import (
     CollectRandomnessPayload,
@@ -58,6 +60,8 @@ class SynchronizedData(
     This state is replicated by the tendermint application.
     """
 
+    # TODO: pointless as already defined on base, although
+    # educative. But see my comment below...
     @property
     def participant_to_selection(self) -> Mapping[str, SelectKeeperPayload]:
         """Get the participant_to_selection."""
@@ -81,17 +85,16 @@ class HelloWorldABCIAbstractRound(AbstractRound[Event, TransactionType], ABC):
 class RegistrationRound(CollectDifferentUntilAllRound, HelloWorldABCIAbstractRound):
     """A round in which the agents get registered"""
 
-    round_id = "registration"
     allowed_tx_type = RegistrationPayload.transaction_type
-    payload_attribute = "sender"
+    payload_attribute = get_name(RegistrationPayload.sender)
 
     def end_block(self) -> Optional[Tuple[BaseSynchronizedData, Event]]:
         """Process the end of the block."""
 
         if self.collection_threshold_reached:
             synchronized_data = self.synchronized_data.update(
-                participants=self.collection,
-                all_participants=self.collection,
+                participants=frozenset(self.collection),
+                all_participants=frozenset(self.collection),
                 synchronized_data_class=SynchronizedData,
             )
             return synchronized_data, Event.DONE
@@ -103,36 +106,36 @@ class CollectRandomnessRound(
 ):
     """A round for collecting randomness"""
 
-    round_id = "collect_randomness"
     allowed_tx_type = CollectRandomnessPayload.transaction_type
-    payload_attribute = "randomness"
+    payload_attribute = get_name(CollectRandomnessPayload.randomness)
     synchronized_data_class = SynchronizedData
     done_event = Event.DONE
     no_majority_event = Event.NO_MAJORITY
-    collection_key = "participant_to_randomness"
-    selection_key = "most_voted_randomness"
+    collection_key = get_name(SynchronizedData.participant_to_randomness)
+    selection_key = get_name(SynchronizedData.most_voted_randomness)
 
 
 class SelectKeeperRound(CollectSameUntilThresholdRound, HelloWorldABCIAbstractRound):
     """A round in a which keeper is selected"""
 
-    round_id = "select_keeper"
     allowed_tx_type = SelectKeeperPayload.transaction_type
-    payload_attribute = "keeper"
+    payload_attribute = get_name(SelectKeeperPayload.keeper)
     synchronized_data_class = SynchronizedData
     done_event = Event.DONE
     no_majority_event = Event.NO_MAJORITY
-    collection_key = "participant_to_selection"
-    selection_key = "most_voted_keeper_address"
+    collection_key = get_name(SynchronizedData.participant_to_selection)
+    selection_key = get_name(SynchronizedData.most_voted_keeper_address)
 
 
 class PrintMessageRound(CollectDifferentUntilAllRound, HelloWorldABCIAbstractRound):
     """A round in which the keeper prints the message"""
 
-    round_id = "print_message"
     allowed_tx_type = PrintMessagePayload.transaction_type
-    payload_attribute = "message"
+    payload_attribute = get_name(PrintMessagePayload.message)
 
+    # TODO: what's the point of this? It might be better
+    # to store the messages on the synchronized state so
+    # the dev actually learns something (see todo above)
     def end_block(self) -> Optional[Tuple[BaseSynchronizedData, Event]]:
         """Process the end of the block."""
         if self.collection_threshold_reached:
@@ -148,9 +151,8 @@ class PrintMessageRound(CollectDifferentUntilAllRound, HelloWorldABCIAbstractRou
 class ResetAndPauseRound(CollectSameUntilThresholdRound, HelloWorldABCIAbstractRound):
     """This class represents the base reset round."""
 
-    round_id = "reset_and_pause"
     allowed_tx_type = ResetPayload.transaction_type
-    payload_attribute = "period_count"
+    payload_attribute = get_name(ResetPayload.period_count)
 
     def end_block(self) -> Optional[Tuple[BaseSynchronizedData, Event]]:
         """Process the end of the block."""
@@ -200,7 +202,7 @@ class HelloWorldAbciApp(AbciApp[Event]):
         reset timeout: 30.0
     """
 
-    initial_round_cls: Type[AbstractRound] = RegistrationRound
+    initial_round_cls: AppState = RegistrationRound
     transition_function: AbciAppTransitionFunction = {
         RegistrationRound: {
             Event.DONE: CollectRandomnessRound,
