@@ -19,17 +19,17 @@
 
 """This module contains the data classes for common apps ABCI application."""
 from enum import Enum
-from typing import Dict, Optional, Set, Tuple, Type
+from typing import Dict, List, Optional, Set, Tuple
 
 from packages.valory.skills.abstract_round_abci.base import (
     AbciApp,
     AbciAppTransitionFunction,
-    AbstractRound,
     AppState,
     BaseSynchronizedData,
     CollectSameUntilAllRound,
     CollectSameUntilThresholdRound,
     DegenerateRound,
+    get_name,
 )
 from packages.valory.skills.registration_abci.payloads import RegistrationPayload
 
@@ -46,21 +46,20 @@ class Event(Enum):
 class FinishedRegistrationRound(DegenerateRound):
     """A round representing that agent registration has finished"""
 
-    round_id = "finished_registration"
-
 
 class FinishedRegistrationFFWRound(DegenerateRound):
     """A fast-forward round representing that agent registration has finished"""
 
-    round_id = "finished_registration_ffw"
-
 
 class RegistrationStartupRound(CollectSameUntilAllRound):
-    """A round in which the agents get registered"""
+    """
+    A round in which the agents get registered.
+
+    This round waits until all agents have registered.
+    """
 
-    round_id = "registration_startup"
     allowed_tx_type = RegistrationPayload.transaction_type
-    payload_attribute = "initialisation"
+    payload_attribute = get_name(RegistrationPayload.initialisation)
     synchronized_data_class = BaseSynchronizedData
 
     def end_block(self) -> Optional[Tuple[BaseSynchronizedData, Event]]:
@@ -71,25 +70,29 @@ class RegistrationStartupRound(CollectSameUntilAllRound):
             synchronized_data = self.synchronized_data.update(
                 participants=frozenset(self.collection),
                 all_participants=frozenset(self.collection),
-                synchronized_data_class=BaseSynchronizedData,
+                synchronized_data_class=self.synchronized_data_class,
             )
             return synchronized_data, Event.FAST_FORWARD
         if self.collection_threshold_reached:
             synchronized_data = self.synchronized_data.update(
                 participants=frozenset(self.collection),
                 all_participants=frozenset(self.collection),
-                synchronized_data_class=BaseSynchronizedData,
+                synchronized_data_class=self.synchronized_data_class,
             )
             return synchronized_data, Event.DONE
         return None
 
 
 class RegistrationRound(CollectSameUntilThresholdRound):
-    """A round in which the agents get registered"""
+    """
+    A round in which the agents get registered.
+
+    This rounds waits until the threshold of agents has been reached
+    and then a further x block confirmations.
+    """
 
-    round_id = "registration"
     allowed_tx_type = RegistrationPayload.transaction_type
-    payload_attribute = "initialisation"
+    payload_attribute = get_name(RegistrationPayload.initialisation)
     required_block_confirmations = 10
     done_event = Event.DONE
     synchronized_data_class = BaseSynchronizedData
@@ -98,14 +101,14 @@ class RegistrationRound(CollectSameUntilThresholdRound):
         """Process the end of the block."""
         if self.threshold_reached:
             self.block_confirmations += 1
-        if (  # contracts are set from previous rounds
+        if (
             self.threshold_reached
             and self.block_confirmations
             > self.required_block_confirmations  # we also wait here as it gives more (available) agents time to join
         ):
             synchronized_data = self.synchronized_data.update(
                 participants=frozenset(self.collection),
-                synchronized_data_class=BaseSynchronizedData,
+                synchronized_data_class=self.synchronized_data_class,
             )
             return synchronized_data, Event.DONE
         if (
@@ -141,7 +144,7 @@ class AgentRegistrationAbciApp(AbciApp[Event]):
         round timeout: 30.0
     """
 
-    initial_round_cls: Type[AbstractRound] = RegistrationStartupRound
+    initial_round_cls: AppState = RegistrationStartupRound
     initial_states: Set[AppState] = {RegistrationStartupRound, RegistrationRound}
     transition_function: AbciAppTransitionFunction = {
         RegistrationStartupRound: {
@@ -162,3 +165,17 @@ class AgentRegistrationAbciApp(AbciApp[Event]):
     event_to_timeout: Dict[Event, float] = {
         Event.ROUND_TIMEOUT: 30.0,
     }
+    db_pre_conditions: Dict[AppState, List[str]] = {
+        RegistrationStartupRound: [],
+        RegistrationRound: [],
+    }
+    db_post_conditions: Dict[AppState, List[str]] = {
+        FinishedRegistrationRound: [
+            get_name(BaseSynchronizedData.participants),
+            get_name(BaseSynchronizedData.all_participants),
+        ],
+        FinishedRegistrationFFWRound: [
+            get_name(BaseSynchronizedData.participants),
+            get_name(BaseSynchronizedData.all_participants),
+        ],
+    }
