@@ -89,7 +89,7 @@ class BaseValidateBehaviourTest(FSMBehaviourBaseCase):
         """Run test."""
         self.fast_forward_to_behaviour(
             self.behaviour,
-            self.behaviour_class.behaviour_id,
+            self.behaviour_class.auto_behaviour_id(),
             SafeDeploymentSynchronizedData(
                 AbciAppDB(
                     setup_data=AbciAppDB.data_to_lists(self.synchronized_data_kwargs)
@@ -101,7 +101,7 @@ class BaseValidateBehaviourTest(FSMBehaviourBaseCase):
                 BaseBehaviour,
                 cast(BaseBehaviour, self.behaviour.current_behaviour),
             ).behaviour_id
-            == self.behaviour_class.behaviour_id
+            == self.behaviour_class.auto_behaviour_id()
         )
         self.behaviour.act_wrapper()
         self.mock_contract_api_request(
@@ -122,7 +122,7 @@ class BaseValidateBehaviourTest(FSMBehaviourBaseCase):
         self._test_done_flag_set()
         self.end_round(self.done_event)
         behaviour = cast(BaseBehaviour, self.behaviour.current_behaviour)
-        assert behaviour.behaviour_id == self.next_behaviour_class.behaviour_id
+        assert behaviour.behaviour_id == self.next_behaviour_class.auto_behaviour_id()
 
 
 class BaseDeployBehaviourTest(FSMBehaviourBaseCase):
@@ -142,7 +142,7 @@ class BaseDeployBehaviourTest(FSMBehaviourBaseCase):
         most_voted_keeper_address = self.skill.skill_context.agent_address
         self.fast_forward_to_behaviour(
             self.behaviour,
-            self.behaviour_class.behaviour_id,
+            self.behaviour_class.auto_behaviour_id(),
             SafeDeploymentSynchronizedData(
                 AbciAppDB(
                     setup_data=AbciAppDB.data_to_lists(
@@ -160,7 +160,7 @@ class BaseDeployBehaviourTest(FSMBehaviourBaseCase):
                 BaseBehaviour,
                 cast(BaseBehaviour, self.behaviour.current_behaviour),
             ).behaviour_id
-            == self.behaviour_class.behaviour_id
+            == self.behaviour_class.auto_behaviour_id()
         )
         self.behaviour.act_wrapper()
 
@@ -224,7 +224,7 @@ class BaseDeployBehaviourTest(FSMBehaviourBaseCase):
         self._test_done_flag_set()
         self.end_round(self.done_event)
         behaviour = cast(BaseBehaviour, self.behaviour.current_behaviour)
-        assert behaviour.behaviour_id == self.next_behaviour_class.behaviour_id
+        assert behaviour.behaviour_id == self.next_behaviour_class.auto_behaviour_id()
 
     def test_not_deployer_act(
         self,
@@ -234,7 +234,7 @@ class BaseDeployBehaviourTest(FSMBehaviourBaseCase):
         most_voted_keeper_address = "a_1"
         self.fast_forward_to_behaviour(
             self.behaviour,
-            self.behaviour_class.behaviour_id,
+            self.behaviour_class.auto_behaviour_id(),
             SafeDeploymentSynchronizedData(
                 AbciAppDB(
                     setup_data=AbciAppDB.data_to_lists(
@@ -252,7 +252,7 @@ class BaseDeployBehaviourTest(FSMBehaviourBaseCase):
                 BaseBehaviour,
                 cast(BaseBehaviour, self.behaviour.current_behaviour),
             ).behaviour_id
-            == self.behaviour_class.behaviour_id
+            == self.behaviour_class.auto_behaviour_id()
         )
         self.behaviour.act_wrapper()
         self._test_done_flag_set()
@@ -260,7 +260,7 @@ class BaseDeployBehaviourTest(FSMBehaviourBaseCase):
         time.sleep(1)
         self.behaviour.act_wrapper()
         behaviour = cast(BaseBehaviour, self.behaviour.current_behaviour)
-        assert behaviour.behaviour_id == self.next_behaviour_class.behaviour_id
+        assert behaviour.behaviour_id == self.next_behaviour_class.auto_behaviour_id()
 
 
 class SafeDeploymentAbciBaseCase(FSMBehaviourBaseCase):
@@ -303,7 +303,7 @@ class TestValidateSafeBehaviour(BaseValidateBehaviourTest, SafeDeploymentAbciBas
     """Test ValidateSafeBehaviour."""
 
     behaviour_class = ValidateSafeBehaviour
-    next_behaviour_class = make_degenerate_behaviour(FinishedSafeRound.round_id)
+    next_behaviour_class = make_degenerate_behaviour(FinishedSafeRound.auto_round_id())
     synchronized_data_kwargs = dict(safe_contract_address="safe_contract_address")
     contract_id = str(GNOSIS_SAFE_CONTRACT_ID)
     done_event = SafeDeploymentEvent.DONE
