@@ -28,6 +28,8 @@ from contextlib import suppress
 from pathlib import Path
 from typing import Optional, Sequence, Tuple
 
+import pytest
+from _pytest.capture import CaptureFixture  # type: ignore
 from aea.test_tools.click_testing import CliRunner
 from click.testing import Result
 
@@ -37,6 +39,11 @@ from autonomy.cli import cli
 class BaseCliTest:
     """Test `autonomy analyse abci` command."""
 
+    @pytest.fixture(autouse=True)
+    def set_capfd_on_cli_runner(self, capfd: CaptureFixture) -> None:
+        """Set pytest capfd on CLI runner"""
+        self.cli_runner.capfd = capfd
+
     t: Path
     cwd: Path
     cli_runner: CliRunner
