@@ -27,7 +27,7 @@ from copy import copy
 from importlib.machinery import ModuleSpec
 from pathlib import Path
 from tempfile import TemporaryDirectory
-from typing import Dict
+from typing import Dict, List, Optional
 
 import click.testing
 import pytest
@@ -91,12 +91,26 @@ class BaseScaffoldFSMTest(AEATestCaseMany):
         with suppress(OSError, FileExistsError, PermissionError):
             shutil.rmtree(str(Path(self.t, self.agent_name)))
 
-    def scaffold_fsm(self, fsm_spec_file: Path) -> click.testing.Result:
+    def scaffold_fsm(
+        self,
+        fsm_spec_file: Path,
+        scaffold_args: Optional[List] = None,
+        cli_args: Optional[List] = None,
+    ) -> click.testing.Result:
         """Scaffold FSM."""
-
+        scaffold_args = scaffold_args or []
+        cli_args = cli_args or []
         *_, skill_name, _ = fsm_spec_file.parts
         skill_name = f"test_skill_{skill_name}"
-        scaffold_args = ["scaffold", "fsm", skill_name, "--local", "--spec"]
+        scaffold_args = [
+            *cli_args,
+            "scaffold",
+            *scaffold_args,
+            "fsm",
+            skill_name,
+            "--local",
+            "--spec",
+        ]
         cli_args = [
             *scaffold_args,
             fsm_spec_file,
@@ -159,3 +173,44 @@ class TestScaffoldFSMAutonomyTests(BaseScaffoldFSMTest):
         result = self.start_subprocess(*cli_args)
         result.wait(timeout=60.0)
         assert result.returncode == 0
+
+
+class TestScaffoldFSMLocalRegistry(BaseScaffoldFSMTest):
+    """Test `scaffold fsm -tlr` subcommand."""
+
+    @property
+    def packages_path(self) -> Path:
+        """
+        Get packages path.
+
+        :return: Path
+        """
+        return self.t / "packages"
+
+    @pytest.mark.parametrize("fsm_spec_file", fsm_specifications)
+    def test_autonomy_test(self, fsm_spec_file: Path) -> None:
+        """Run autonomy test on the scaffolded skill"""
+
+        *_, skill_name, _ = fsm_spec_file.parts
+        skill_name = f"test_skill_{skill_name}"
+        scaffold_result = self.scaffold_fsm(
+            fsm_spec_file,
+            scaffold_args=["-tlr"],
+            cli_args=["--registry-path", self.packages_path],
+        )
+        assert scaffold_result.exit_code == 0
+        assert (self.packages_path / self.author / "skills" / skill_name).exists()
+        cli_args = [
+            "-m",
+            "aea.cli",
+            "test",
+            "by-path",
+            str(self.packages_path / self.author / "skills" / skill_name),
+        ]
+
+        # we use a subprocess rather than click.CliRunner because we want to isolate
+        # the Python environment of the current pytest process with the subcall to pytest.main
+        # from the AEA command `aea test by-path ...`
+        result = self.start_subprocess(*cli_args)
+        result.wait(timeout=60.0)
+        assert result.returncode == 0
