@@ -21,7 +21,7 @@
 
 from pathlib import Path
 from tempfile import TemporaryDirectory
-from typing import Any, cast
+from typing import Any, Optional, cast
 from unittest import mock
 
 import pytest
@@ -51,9 +51,17 @@ def get_dummy_service() -> Service:
 
 
 @pytest.mark.parametrize("generator_cls", (DockerComposeGenerator, KubernetesGenerator))
-def test_versioning(generator_cls: Any) -> None:
+@pytest.mark.parametrize("image_version", [None, "0.1.0"])
+@pytest.mark.parametrize("use_hardhat", [False, True])
+@pytest.mark.parametrize("use_acn", [False, True])
+def test_versioning(
+    generator_cls: Any, image_version: Optional[str], use_hardhat: bool, use_acn: bool
+) -> None:
     """Test versioning in builds."""
 
+    generate_kwargs = locals()
+    generate_kwargs.pop("generator_cls")
+
     with TemporaryDirectory() as temp_dir:
         with cd(temp_dir), mock.patch(
             "autonomy.deploy.base.load_service_config",
@@ -73,9 +81,6 @@ def test_versioning(generator_cls: Any) -> None:
                 ),
             )
 
-            deployment_generator.generate()
-            assert f"valory/oar-oracle:{AGENT.hash}" in deployment_generator.output
-
-            image_version = "0.1.0"
-            deployment_generator.generate(image_version=image_version)
-            assert f"valory/oar-oracle:{image_version}" in deployment_generator.output
+            deployment_generator.generate(**generate_kwargs)
+            expected = f"valory/oar-oracle:{image_version or AGENT.hash}"
+            assert expected in deployment_generator.output
