@@ -44,11 +44,13 @@ from deployments.Dockerfiles.tendermint import app  # type: ignore
 from deployments.Dockerfiles.tendermint.app import TendermintNode  # type: ignore
 from deployments.Dockerfiles.tendermint.app import (  # type: ignore
     CONFIG_OVERRIDE,
+    DOCKER_INTERNAL_HOST,
     PeriodDumper,
     create_app,
     get_defaults,
     load_genesis,
     override_config_toml,
+    update_peers,
 )
 from deployments.Dockerfiles.tendermint.tendermint import (  # type: ignore
     TendermintParams,
@@ -57,6 +59,17 @@ from deployments.Dockerfiles.tendermint.tendermint import (  # type: ignore
 
 ENCODING = "utf-8"
 VERSION = "0.34.19"
+DUMMY_CONFIG_TOML = """
+# Comma separated list of seed nodes to connect to
+seeds = ""
+
+# Comma separated list of nodes to keep persistent connections to
+persistent_peers = "dummy_peer1@localhost:80,dummy_peer2@localhost:81"
+
+# UPNP port forwarding
+upnp = false
+"""
+
 
 wait_for_node_to_run = pytest.mark.usefixtures("wait_for_node")
 wait_for_occupied_rpc_port = pytest.mark.usefixtures("wait_for_occupied_rpc_port")
@@ -259,6 +272,7 @@ class TestTendermintServerApp(BaseTendermintServerTest):
             params = data.get("params")
             assert params
             assert params.pop("address")
+            assert params.pop("peer_id")
             pub_key = params.pop("pub_key")
             assert pub_key.pop("type")
             assert pub_key.pop("value")
@@ -292,7 +306,9 @@ class TestTendermintServerApp(BaseTendermintServerTest):
             # 1. check params are in validator set
             response = client.get("/params")
             assert response.status_code == 200
-            params = cast(JSONLike, response.get_json()).get("params")
+            response_data = cast(Dict, response.get_json())
+            params = cast(Dict, response_data["params"])
+            params.pop("peer_id", None)
             params["name"], params["power"] = "", "10"
             assert params in genesis_config["validators"]
 
@@ -484,3 +500,66 @@ class TestTendermintBufferWorking(BaseTendermintServerTest):
                 raise AssertionError(e)
 
             time.sleep(1)
+
+
+def test_update_peers() -> None:
+    """Test update peers."""
+
+    validators = [
+        {
+            "hostname": f"host_{i}",
+            "p2p_port": i * 10,
+            "peer_id": f"peer_{i}",
+        }
+        for i in range(2)
+    ]
+
+    with tempfile.TemporaryDirectory() as temp_dir:
+        config_file = Path(temp_dir, "config.toml")
+        config_file.write_text(DUMMY_CONFIG_TOML)
+
+        update_peers(validators=validators, config_path=config_file)
+
+        updated_content = config_file.read_text()
+
+        # make sure we don't update anything else
+        assert """seeds = """ "" in updated_content
+        assert "upnp = false" in updated_content
+
+        for val in validators:
+            assert (
+                str(val["peer_id"])
+                + "@"
+                + str(val["hostname"])
+                + ":"
+                + str(val["p2p_port"])
+                in updated_content
+            )
+
+
+def test_update_peers_internal_host() -> None:
+    """Test update peers."""
+
+    validators = [{"hostname": "localhost", "p2p_port": 80, "peer_id": "peer"}]
+
+    with tempfile.TemporaryDirectory() as temp_dir:
+        config_file = Path(temp_dir, "config.toml")
+        config_file.write_text(DUMMY_CONFIG_TOML)
+
+        update_peers(validators=validators, config_path=config_file)
+
+        updated_content = config_file.read_text()
+
+        # make sure we don't update anything else
+        assert """seeds = """ "" in updated_content
+        assert "upnp = false" in updated_content
+
+        for val in validators:
+            assert (
+                str(val["peer_id"])
+                + "@"
+                + DOCKER_INTERNAL_HOST
+                + ":"
+                + str(val["p2p_port"])
+                in updated_content
+            )
